@@ -3,6 +3,7 @@ import struct as _struct
 import platform as _platform
 import re
 from archinfo.archerror import ArchError
+import copy
 
 l = logging.getLogger("archinfo.arch")
 l.addHandler(logging.NullHandler())
@@ -100,7 +101,7 @@ class Arch:
     A good number of assumptions are made that code is being processed under the VEX IR - for instance, it is expected
     the register file offsets are expected to match code generated by PyVEX.
 
-    Arches maybe compared with == and !=.
+    Arches may be compared with == and !=.
 
     :ivar str name: The name of the arch
     :ivar int bits: The number of bits in a word
@@ -166,11 +167,8 @@ class Arch:
         if instruction_endness is not None:
             self.instruction_endness = instruction_endness
 
-        if self.vex_support:
-            if _pyvex:
-                self.vex_archinfo = _pyvex.default_vex_archinfo()
-        else:
-            self._vex_archinfo = None
+        if self.vex_support and _pyvex:
+            self.vex_archinfo = _pyvex.default_vex_archinfo()
 
         if endness == Endness.BE:
             if self.vex_archinfo:
@@ -267,10 +265,11 @@ class Arch:
         """
         Produce a copy of this instance of this arch.
         """
-        new_arch = type(self)(self.memory_endness)
-        new_arch.vex_archinfo = self.vex_archinfo.copy() if self.vex_archinfo is not None else None
-
-        return new_arch
+        res = copy.copy(self)
+        res.vex_archinfo = copy.deepcopy(self.vex_archinfo)
+        res._cs = None
+        res._ks = None
+        return res
 
     def __repr__(self):
         return '<Arch %s (%s)>' % (self.name, self.memory_endness[-2:])
@@ -455,6 +454,13 @@ class Arch:
 
         return encoding
 
+    def disasm(self, bytestring, addr=0, thumb=False):
+        if thumb and not hasattr(self, 'keystone_thumb'):
+            l.warning("Specified thumb=True on non-ARM architecture")
+            thumb = False
+        cs = self.capstone_thumb if thumb else self.capstone # pylint: disable=no-member
+        return '\n'.join('%#x:\t%s %s' % (insn.address, insn.mnemonic, insn.op_str) for insn in cs.disasm(bytestring, addr))
+
     def translate_dynamic_tag(self, tag):
         try:
             return self.dynamic_tag_translation[tag]
